@@ -39,6 +39,7 @@ import org.objectweb.asm.AnnotationVisitor;
 import org.objectweb.asm.Attribute;
 import org.objectweb.asm.ClassReader;
 import org.objectweb.asm.ClassVisitor;
+import org.objectweb.asm.ClassWriter;
 import org.objectweb.asm.FieldVisitor;
 import org.objectweb.asm.Label;
 import org.objectweb.asm.MethodVisitor;
@@ -161,7 +162,7 @@ public class CheckClassAdapter extends ClassVisitor {
    * @param classVisitor the class visitor to which this adapter must delegate calls.
    */
   public CheckClassAdapter(final ClassVisitor classVisitor) {
-    this(classVisitor, true);
+    this(classVisitor, /* checkDataFlow = */ true);
   }
 
   /**
@@ -169,8 +170,7 @@ public class CheckClassAdapter extends ClassVisitor {
    * Instead, they must use the {@link #CheckClassAdapter(int, ClassVisitor, boolean)} version.
    *
    * @param classVisitor the class visitor to which this adapter must delegate calls.
-   * @param checkDataFlow whether to perform basic data flow checks. This option requires valid
-   *     maxLocals and maxStack values.
+   * @param checkDataFlow whether to perform basic data flow checks.
    * @throws IllegalStateException If a subclass calls this constructor.
    */
   public CheckClassAdapter(final ClassVisitor classVisitor, final boolean checkDataFlow) {
@@ -183,13 +183,11 @@ public class CheckClassAdapter extends ClassVisitor {
   /**
    * Constructs a new {@link CheckClassAdapter}.
    *
-   * @param api the ASM API version implemented by this visitor. Must be one of {@link
-   *     Opcodes#ASM4}, {@link Opcodes#ASM5}, {@link Opcodes#ASM6}, {@link Opcodes#ASM7}, {@link
-   *     Opcodes#ASM8} or {@link Opcodes#ASM9}.
+   * @param api the ASM API version implemented by this visitor. Must be one of the {@code
+   *     ASM}<i>x</i> values in {@link Opcodes}.
    * @param classVisitor the class visitor to which this adapter must delegate calls.
    * @param checkDataFlow {@literal true} to perform basic data flow checks, or {@literal false} to
-   *     not perform any data flow check (see {@link CheckMethodAdapter}). This option requires
-   *     valid maxLocals and maxStack values.
+   *     not perform any data flow check (see {@link CheckMethodAdapter}).
    */
   protected CheckClassAdapter(
       final int api, final ClassVisitor classVisitor, final boolean checkDataFlow) {
@@ -430,7 +428,8 @@ public class CheckClassAdapter extends ClassVisitor {
       final String signature,
       final String[] exceptions) {
     checkState();
-    checkAccess(
+    checkMethodAccess(
+        version,
         access,
         Opcodes.ACC_PUBLIC
             | Opcodes.ACC_PRIVATE
@@ -460,21 +459,17 @@ public class CheckClassAdapter extends ClassVisitor {
       }
     }
     CheckMethodAdapter checkMethodAdapter;
+    MethodVisitor methodVisitor =
+        super.visitMethod(access, name, descriptor, signature, exceptions);
     if (checkDataFlow) {
+      if (cv instanceof ClassWriter) {
+        methodVisitor =
+            new CheckMethodAdapter.MethodWriterWrapper(api, (ClassWriter) cv, methodVisitor);
+      }
       checkMethodAdapter =
-          new CheckMethodAdapter(
-              api,
-              access,
-              name,
-              descriptor,
-              super.visitMethod(access, name, descriptor, signature, exceptions),
-              labelInsnIndices);
+          new CheckMethodAdapter(api, access, name, descriptor, methodVisitor, labelInsnIndices);
     } else {
-      checkMethodAdapter =
-          new CheckMethodAdapter(
-              api,
-              super.visitMethod(access, name, descriptor, signature, exceptions),
-              labelInsnIndices);
+      checkMethodAdapter = new CheckMethodAdapter(api, methodVisitor, labelInsnIndices);
     }
     checkMethodAdapter.version = version;
     return checkMethodAdapter;
@@ -555,6 +550,23 @@ public class CheckClassAdapter extends ClassVisitor {
     }
   }
 
+  /**
+   * Checks that the given access flags do not contain invalid flags for a method. This method also
+   * checks that mutually incompatible flags are not set simultaneously.
+   *
+   * @param version the class version.
+   * @param access the method access flags to be checked.
+   * @param possibleAccess the valid access flags.
+   */
+  private static void checkMethodAccess(
+      final int version, final int access, final int possibleAccess) {
+    checkAccess(access, possibleAccess);
+    if ((version & 0xFFFF) < Opcodes.V17
+        && Integer.bitCount(access & (Opcodes.ACC_STRICT | Opcodes.ACC_ABSTRACT)) > 1) {
+      throw new IllegalArgumentException("strictfp and abstract are mutually exclusive: " + access);
+    }
+  }
+
   /**
    * Checks that the given name is a fully qualified name, using dots.
    *
@@ -1114,7 +1126,11 @@ public class CheckClassAdapter extends ClassVisitor {
       if (name.charAt(endIndex - 1) == ';') {
         endIndex--;
       }
-      return name.substring(lastSlashIndex + 1, endIndex);
+      int lastBracketIndex = name.lastIndexOf('[');
+      if (lastBracketIndex == -1) {
+        return name.substring(lastSlashIndex + 1, endIndex);
+      }
+      return name.substring(0, lastBracketIndex + 1) + name.substring(lastSlashIndex + 1, endIndex);
     }
   }
 }
