@@ -291,9 +291,8 @@ public abstract class Printer {
   private static final String UNSUPPORTED_OPERATION = "Must be overridden";
 
   /**
-   * The ASM API version implemented by this class. The value of this field must be one of {@link
-   * Opcodes#ASM4}, {@link Opcodes#ASM5}, {@link Opcodes#ASM6}, {@link Opcodes#ASM7}, {@link
-   * Opcodes#ASM8} or {@link Opcodes#ASM9}.
+   * The ASM API version implemented by this class. The value of this field must be one of the
+   * {@code ASM}<i>x</i> values in {@link Opcodes}.
    */
   protected final int api;
 
@@ -319,8 +318,8 @@ public abstract class Printer {
   /**
    * Constructs a new {@link Printer}.
    *
-   * @param api the ASM API version implemented by this printer. Must be one of {@link
-   *     Opcodes#ASM4}, {@link Opcodes#ASM5}, {@link Opcodes#ASM6} or {@link Opcodes#ASM7}.
+   * @param api the ASM API version implemented by this printer. Must be one of the {@code
+   *     ASM}<i>x</i> values in {@link Opcodes}.
    */
   protected Printer(final int api) {
     this.api = api;
@@ -918,10 +917,10 @@ public abstract class Printer {
    *
    * @param opcode the opcode of the local variable instruction to be visited. This opcode is either
    *     ILOAD, LLOAD, FLOAD, DLOAD, ALOAD, ISTORE, LSTORE, FSTORE, DSTORE, ASTORE or RET.
-   * @param var the operand of the instruction to be visited. This operand is the index of a local
-   *     variable.
+   * @param varIndex the operand of the instruction to be visited. This operand is the index of a
+   *     local variable.
    */
-  public abstract void visitVarInsn(int opcode, int var);
+  public abstract void visitVarInsn(int opcode, int varIndex);
 
   /**
    * Method instruction. See {@link org.objectweb.asm.MethodVisitor#visitTypeInsn}.
@@ -1035,10 +1034,10 @@ public abstract class Printer {
   /**
    * Method instruction. See {@link org.objectweb.asm.MethodVisitor#visitIincInsn}.
    *
-   * @param var index of the local variable to be incremented.
+   * @param varIndex index of the local variable to be incremented.
    * @param increment amount to increment the local variable by.
    */
-  public abstract void visitIincInsn(int var, int increment);
+  public abstract void visitIincInsn(int varIndex, int increment);
 
   /**
    * Method instruction. See {@link org.objectweb.asm.MethodVisitor#visitTableSwitchInsn}.
@@ -1269,7 +1268,7 @@ public abstract class Printer {
   /**
    * Prints a the given class to the given output.
    *
-   * <p>Command line arguments: [-debug] &lt;binary class name or class file name &gt;
+   * <p>Command line arguments: [-nodebug] &lt;binary class name or class file name &gt;
    *
    * @param args the command line arguments.
    * @param usage the help message to show when command line arguments are incorrect.
@@ -1285,7 +1284,9 @@ public abstract class Printer {
       final PrintWriter output,
       final PrintWriter logger)
       throws IOException {
-    if (args.length < 1 || args.length > 2 || (args[0].equals("-debug") && args.length != 2)) {
+    if (args.length < 1
+        || args.length > 2
+        || ((args[0].equals("-debug") || args[0].equals("-nodebug")) && args.length != 2)) {
       logger.println(usage);
       return;
     }
@@ -1294,7 +1295,7 @@ public abstract class Printer {
 
     String className;
     int parsingOptions;
-    if (args[0].equals("-debug")) {
+    if (args[0].equals("-nodebug")) {
       className = args[1];
       parsingOptions = ClassReader.SKIP_DEBUG;
     } else {
@@ -1308,8 +1309,6 @@ public abstract class Printer {
       // Can't fix PMD warning for 1.5 compatibility.
       try (InputStream inputStream = new FileInputStream(className)) { // NOPMD(AvoidFileStream)
         new ClassReader(inputStream).accept(traceClassVisitor, parsingOptions);
-      } catch (IOException ioe) {
-        throw ioe;
       }
     } else {
       new ClassReader(className).accept(traceClassVisitor, parsingOptions);
